C***********************************************************************
C
C  PROGRAM        LAYOUT  SUBROUTINE        
C
C  VERSION        Scott Hannon, 24 February 1998
C                 Based on LAYOT2 version 3.Y by David Edwards 10/05/93
C
C                 Last updated 5 July 2001: rename Z1000 to ZSURF; add
C                 PSURF to call; input HBOUND is now m so divide by
C                 by 1000 to convert to km.
C 
C  DESCRIPTION    Writes an output file in the format used by kCARTA
C
C***********************************************************************

       SUBROUTINE LAYOUT( IOP, TITLEP, FNPROF, MNAFGL, NGASES, LISTG,
     $    GORDER, HBOUND, PBOUND, PAVG, TAVG, PARTPP, DELT, GASAMT,
     $    LZ, LSPLIN, LSVP, LDRY, FNAFGL, IWAT, TOFF, PSURF, ZSURF)

C-----------------------------------------------------------------------
C      INCLUDE FILES
C-----------------------------------------------------------------------
      include 'incLAY.f'


C-----------------------------------------------------------------------
C      ARGUMENTS
C-----------------------------------------------------------------------
C      Input:
       INTEGER    IOP
       INTEGER NGASES
       INTEGER  LISTG( MXGAS)
       INTEGER GORDER( MXGAS)
       INTEGER   IWAT
       INTEGER MNAFGL
       REAL HBOUND(MYNLAY+1)
       REAL PBOUND(MYNLAY+1)
       REAL   PAVG(MYNLAY)
       REAL   TAVG(MYNLAY)
       REAL PARTPP( MXGAS,MYNLAY)
       REAL   DELT(MYNLAY)
       REAL GASAMT(MYNLAY, MXGAS)
       REAL   TOFF
       REAL  PSURF
       REAL  ZSURF
       CHARACTER*70 FNPROF
       CHARACTER*80 TITLEP
       CHARACTER*70 FNAFGL
       LOGICAL     LZ
       LOGICAL LSPLIN
       LOGICAL   LSVP
       LOGICAL   LDRY
C
C      Output:
C      none


C-----------------------------------------------------------------------
C      LOCAL VARIABLES
C-----------------------------------------------------------------------
       INTEGER     IG
       INTEGER   IGAS
       INTEGER     II
       INTEGER   ILAY
       INTEGER  IPATH
       INTEGER    IPF
       INTEGER    IPS
       INTEGER  NOPTH
       REAL COLTOT( MXGAS)
       REAL RAYTOT( MXGAS)
       CHARACTER*9    CHA(    63)
       CHARACTER*21  ATMOD(     6)


C-----------------------------------------------------------------------
C      DATA BLOCKS
C-----------------------------------------------------------------------
C      HITRAN molecule IDs
       DATA (CHA(IG),IG=1,32)/
     $    '** H2O **','** CO2 **','** O3 ***','** N2O **','** CO ***',
     $    '** CH4 **','** O2 ***','** NO ***','** SO2 **','** NO2 **',
     $    '** NH3 **','** HNO3 *','** OH ***','** HF ***','** HCl **',
     $    '** HBr **','** HI ***','** ClO **','** OCS **','** H2CO *',
     $    '** HOCl *','** N2 ***','** HCN **','* CH3Cl *','** H2O2 *',
     $    '** C2H2 *','** C2H6 *','** PH3 **','* COF2 **','** SF6 **',
     $    '** H2S **','*HCOOH **'/
C
C      Cross-section gases molecule IDs
       DATA (CHA(IG),IG=51,63)/
     $    '* CFC11 *','* CFC12 *','* CFC13 *','* CFC14 *','* CFC21 *',
     $    '* CFC22 *','* CFC113*','* CFC114*','* CFC115*','** CCl4 *',
     $    '* ClONO2*','** N2O5 *','** HNO4 *'/
C
C      AFGL standard models
       DATA ATMOD/
     $    '1. Tropical          ','2. Midlatiude Summer ',
     $    '3. Midlatitude Winter','4. Subarctic Summer  ',
     $    '5. Subarctic Winter  ','6. U.S. Standard     '/


C***********************************************************************
C***********************************************************************
C      EXECUTABLE CODE begins below
C***********************************************************************
C***********************************************************************
C
       NOPTH=NGASES*MYNLAY
C
C      ---------------------------------
C      Write output file header comments
C      ---------------------------------
       WRITE(IOP,1010)
 1010  FORMAT('! This is a KLAYERS output file for use with kCARTA',
     $    /,'!')
C
       WRITE(IOP,1030) TITLEP
 1030  FORMAT('! ',A80,/,'!')
C
       WRITE(IOP,1040) FNPROF
 1040  FORMAT('! User''s atmospheric profile taken from:',/,'! ',
     $    A70,/,'!')
C
       IF (LZ) THEN
          WRITE(IOP,1050)
 1050     FORMAT('! User''s profile contained altitude data',/,'!')
       ELSE
          IF (LSPLIN) WRITE(IOP,1055)
 1055     FORMAT('! User profile interpolated using a cubic spline',
     $       /,'!')
       ENDIF
C
       WRITE(IOP,1060) MNAFGL,FNAFGL
 1060  FORMAT('! Users profile supplemented by AFGL model:',I2,
     $    ' from:',/,'! ',A70)
C
       IF (LSPLIN) THEN
          WRITE(IOP,1070)
 1070     FORMAT('! AFGL profile interpolated using a cubic spline',
     $       /,'!')
       ELSE
          WRITE(IOP,1075)
 1075     FORMAT('!')
       ENDIF
C
       IF (ABS(TOFF) .GT. 0.01) THEN
          WRITE(IOP,1110) TOFF
 1110     FORMAT('! Profile temperature offset = ',F7.3,'K',/,'!')
       ELSE
          TOFF=0.0
       ENDIF
C
       IF (LSVP) THEN
          WRITE(IOP,1120)
 1120     FORMAT('! Checked/corrected water for over-saturation',
     $    /,'!')
       ELSE
          WRITE(IOP,1125)
 1125     FORMAT('! Did not check water for over-saturation',
     $    /,'!')
       ENDIF
C
       IF (LDRY) THEN
          WRITE(IOP,1140)
 1140     FORMAT(
     $    '! Mixing ratios were adjusted for water displacement',
     $    /,'!')
       ELSE
          WRITE(IOP,1145)
 1145     FORMAT(
     $    '! Did not adjust mixing ratios for water displacement',
     $    /,'!')
       ENDIF
C
       IF (IWAT .EQ. 0) THEN
          WRITE(IOP,1160)
 1160     FORMAT(
     $    '! Warning! Air molecular weight not adjusted for water',
     $    /,'!')
       ENDIF
C
       WRITE(IOP,1170) PSURF, ZSURF
 1170  FORMAT('! Altitude at ',F6.1,' mb was specified as:',
     $    F7.1,' meters.',/,'!')

       WRITE(IOP,1180) NGRID
 1180  FORMAT('! Integration accuracy criterion parameter =',I4,/,'!')
C
C      -------------------------
C      Write the layer path data
C      -------------------------
       WRITE(IOP,1200) NOPTH
 1200  FORMAT('! TOTAL NO. OF PATHS CALCULATED:',/,I4,/,'!')
C
C      Loop over gases
       DO IG=1,NGASES
C         Loop over layers
          DO ILAY=1,MYNLAY
             IGAS = LISTG(IG)
             IPATH=(IG-1)*MYNLAY + ILAY
             II = GORDER(IG)
C
             WRITE(IOP,1220) IPATH, CHA(IGAS), HBOUND(ILAY)/1000,
     $          HBOUND(ILAY+1)/1000, PBOUND(ILAY), PBOUND(ILAY+1),
     $          (HBOUND(ILAY+1)-HBOUND(ILAY))/1000, 0.0
 1220        FORMAT('! PATH',I4,1X,A9,' HEIGHTS:',F8.3,' -',F8.3,
     $          ' km,',1PE10.3,' -',E10.3,' mb.',/,
     $          '! RAY LENGTH =',0PF9.4,' km, THETA =',1PE11.4,'.')
C
             WRITE(IOP,1240) IGAS, GASAMT(ILAY,II),
     $          TAVG(ILAY)+TOFF, DELT(ILAY), PAVG(ILAY),
     $          (PBOUND(ILAY)-PBOUND(ILAY+1))/1013.25,
     $          PARTPP(II,ILAY), 0.5*(HBOUND(ILAY)+HBOUND(ILAY+1))/1000
 1240        FORMAT(I3,',',1PE12.4,',',0PF9.3,',',
     $          0PF9.3,',',3(1PE12.4,','),0PF9.3)
C
          ENDDO
       ENDDO
C
C      --------------
C      Path summaries
C      --------------
       WRITE(IOP,1300)
 1300  FORMAT('!',/'!')
C
       DO 40 IG=1,NGASES
          II=GORDER(IG)
          COLTOT(IG) = 0.0
          RAYTOT(IG) = 0.0
          DO 50 ILAY=1,MYNLAY
             IPATH = (IG-1)*MYNLAY + ILAY
             COLTOT(IG)=COLTOT(IG) + GASAMT(ILAY,II)
             RAYTOT(IG)=RAYTOT(IG) + (HBOUND(ILAY+1)-HBOUND(ILAY))/1000
   50     CONTINUE
C
          IPS = (IG-1)*MYNLAY + 1
          IPF = IG*MYNLAY
C         
          WRITE(IOP,1320) IPS, IPF, LISTG(IG), CHA(LISTG(IG)),
     $       COLTOT(IG), RAYTOT(IG)
 1320     FORMAT(
     $    '!  PATHS ',I4,' -- ',I4,/,
     $    '!  GAS ID',I3,1X,A9,/,
     $    '!  TOTAL GAS COLUMN AMOUNT  [kiloMoles/cm2] =',1PE11.4,/,
     $    '!  TOTAL RAY PATH LENGTH               [km] =',0PF11.3,/,
     $    '! ')
   40  CONTINUE
C
       RETURN
       END
