C REGOUT is a variant of LAYOUT; it forces all gases except water,
C ozone (and maybe methane and CO) to use the reference amount.
C***********************************************************************
C
C  PROGRAM        REGOUT  SUBROUTINE        
C
C  VERSION        24 February 1998
C                 Previous last update: Scott Hannon, 19 July 2000
C                 Last updated 5 July 2001; change Z1000 to ZSURF; add
C                 PSURF to call; input HBOUND is now m so must divide
C                 1000 to get km; rename REGOUT (was LAYOUT_reg).
C 
C  DESCRIPTION    Writes an output file in the format used by kCARTA
C
C***********************************************************************

       SUBROUTINE REGOUT( IOP, TITLEP, FNPROF, MNAFGL, NGASES, LISTG,
     $    GORDER, HBOUND, PBOUND, PAVG, TAVG, PARTPP, DELT, GASAMT,
     $    LZ, LSPLIN, LSVP, LDRY, FNAFGL, IWAT, TOFF, PSURF, ZSURF)

C-----------------------------------------------------------------------
C      INCLUDE FILES
C-----------------------------------------------------------------------
      include 'incLAY.f'

      INTEGER NREG
C     Number of gases NOT using ref prof amount
C     Usually: 2,3, or 4 (for H2O plus one or more of O3, CO, and CH4)
      PARAMETER (NREG=3)


C-----------------------------------------------------------------------
C      ARGUMENTS
C-----------------------------------------------------------------------
C      Input:
       INTEGER    IOP
       INTEGER NGASES
       INTEGER  LISTG( MXGAS)
       INTEGER GORDER( MXGAS)
       INTEGER   IWAT
       INTEGER MNAFGL
       REAL HBOUND(MYNLAY+1)
       REAL PBOUND(MYNLAY+1)
       REAL   PAVG(MYNLAY)
       REAL   TAVG(MYNLAY)
       REAL PARTPP( MXGAS,MYNLAY)
       REAL   DELT(MYNLAY)
       REAL GASAMT(MYNLAY, MXGAS)
       REAL   TOFF
       REAL  PSURF
       REAL  ZSURF
       CHARACTER*70 FNPROF
       CHARACTER*80 TITLEP
       CHARACTER*70 FNAFGL
       LOGICAL     LZ
       LOGICAL LSPLIN
       LOGICAL   LSVP
       LOGICAL   LDRY
C
C      Output:
C      none


C-----------------------------------------------------------------------
C      LOCAL VARIABLES
C-----------------------------------------------------------------------
       INTEGER     IG
       INTEGER   IGAS
       INTEGER     II
       INTEGER   ILAY
       INTEGER  IPATH
       INTEGER    IPF
       INTEGER    IPS
       INTEGER      J
       INTEGER  NOPTH
       REAL COLTOT( MXGAS)
       REAL RAYTOT( MXGAS)
       CHARACTER*9    CHA(    63)
       CHARACTER*21  ATMOD(     6)


C      -----------------------------------------------------------------
C      Variables for use with regression profile version of layers only
       INTEGER IDREG(NREG) ! gas IDs of variable gases
       LOGICAL USEREF
       REAL RJUNK1, RJUNK2, RJUNK3
       REAL REFAMT(MYNLAY)
       CHARACTER*79  CLINE
       CHARACTER*79 RFNAME
       INTEGER   IOP2
       INTEGER   IERR

       CHARACTER*80 CWORK1
       CHARACTER*2 CWORK2
       INTEGER LENC1

cC      CO2 amount scaling factor
c       INTEGER  IDCO2
c       REAL CO2MLT


C-----------------------------------------------------------------------
C      DATA BLOCKS
C-----------------------------------------------------------------------
C      HITRAN molecule IDs
       DATA (CHA(IG),IG=1,32)/
     $    '** H2O **','** CO2 **','** O3 ***','** N2O **','** CO ***',
     $    '** CH4 **','** O2 ***','** NO ***','** SO2 **','** NO2 **',
     $    '** NH3 **','** HNO3 *','** OH ***','** HF ***','** HCl **',
     $    '** HBr **','** HI ***','** ClO **','** OCS **','** H2CO *',
     $    '** HOCl *','** N2 ***','** HCN **','* CH3Cl *','** H2O2 *',
     $    '** C2H2 *','** C2H6 *','** PH3 **','* COF2 **','** SF6 **',
     $    '** H2S **','*HCOOH **'/
C
C      Cross-section gases molecule IDs
       DATA (CHA(IG),IG=51,63)/
     $    '* CFC11 *','* CFC12 *','* CFC13 *','* CFC14 *','* CFC21 *',
     $    '* CFC22 *','* CFC113*','* CFC114*','* CFC115*','** CCl4 *',
     $    '* ClONO2*','** N2O5 *','** HNO4 *'/
C
C      AFGL standard models
       DATA ATMOD/
     $    '1. Tropical          ','2. Midlatiude Summer ',
     $    '3. Midlatitude Winter','4. Subarctic Summer  ',
     $    '5. Subarctic Winter  ','6. U.S. Standard     '/


C***********************************************************************
C***********************************************************************
C      EXECUTABLE CODE begins below
C***********************************************************************
C***********************************************************************
C
C      Unit number to use when reading for refgas profs
       IOP2=15
C
C      Gas IDs that will not be forced to use ref prof amount
       IDREG(1)=1  ! H2O water
       IDREG(2)=3  ! O3 ozone
       IDREG(3)=5  ! CO carbon monoxide
c       IDREG(4)=6  ! CH4 methane
C
cC      Assign the CO2 gas ID (HITRAN ID = 2) and amount scaling factor.
c       IDCO2=2
c       CO2MLT=1.0
       NOPTH=NGASES*MYNLAY
C
C      ---------------------------------
C      Write output file header comments
C      ---------------------------------
       WRITE(IOP,1010)
 1010  FORMAT('! This is a KLAYERS_reg output file for use with kCARTA',
     $    /,'!')
C
       WRITE(IOP,1030) TITLEP
 1030  FORMAT('! ',A80,/,'!')
C
       WRITE(IOP,1040) FNPROF
 1040  FORMAT('! User''s atmospheric profile taken from:',/,'! ',
     $    A70,/,'!')
C
       IF (LZ) THEN
          WRITE(IOP,1050)
 1050     FORMAT('! User''s profile contained altitude data',/,'!')
       ELSE
          IF (LSPLIN) WRITE(IOP,1055)
 1055     FORMAT('! User profile interpolated using a cubic spline',
     $       /,'!')
       ENDIF
C
       WRITE(IOP,1060) MNAFGL,FNAFGL
 1060  FORMAT('! Users profile supplemented by AFGL model:',I2
     $    ' from:',/,'! ',A70)
C
       IF (LSPLIN) THEN
          WRITE(IOP,1070)
 1070     FORMAT('! AFGL profile interpolated using a cubic spline',
     $       /,'!')
       ELSE
          WRITE(IOP,1075)
 1075     FORMAT('!')
       ENDIF
C
       IF (ABS(TOFF) .GT. 0.01) THEN
          WRITE(IOP,1110) TOFF
 1110     FORMAT('! Profile temperature offset = ',F7.3,'K',/,'!')
       ELSE
          TOFF=0.0
       ENDIF
C
       IF (LSVP) THEN
          WRITE(IOP,1120)
 1120     FORMAT('! Checked/corrected water for over-saturation',
     $    /,'!')
       ELSE
          WRITE(IOP,1125)
 1125     FORMAT('! Did not check water for over-saturation',
     $    /,'!')
       ENDIF
C
       IF (LDRY) THEN
          WRITE(IOP,1140)
 1140     FORMAT(
     $    '! Mixing ratios were adjusted for water displacement',
     $    /,'!')
       ELSE
          WRITE(IOP,1145)
 1145     FORMAT(
     $    '! Did not adjust mixing ratios for water displacement',
     $    /,'!')
       ENDIF
C
       IF (IWAT .EQ. 0) THEN
          WRITE(IOP,1160)
 1160     FORMAT(
     $    '! Warning! Air molecular weight not adjusted for water',
     $    /,'!')
       ENDIF
C
       WRITE(IOP,1170) PSURF, ZSURF
 1170  FORMAT('! Altitude at ', F6.1, ' mb was specified as:',
     $    F7.1,' meters.',/,'!')

       WRITE(IOP,1180) NGRID
 1180  FORMAT('! Integration accuracy criterion parameter =',I4,/,'!')
C
       WRITE(IOP,1190) (IDREG(J),J=1,NREG)
 1190  FORMAT('! All gases are ref amount except:',15(X,I2))
C
c       WRITE(IOP,1195) IDCO2, CO2MLT
c 1195  FORMAT('! CO2 (gas ID',I3,') is ref amount scaled by',1PE11.4)
C

C      Length of refgas file name without gas ID number at end
       LENC1=INDEX(NAMREF,' ') - 1

C      -------------------------
C      Write the layer path data
C      -------------------------
       WRITE(IOP,1200) NOPTH
 1200  FORMAT('! TOTAL NO. OF PATHS CALCULATED:',/,I4,/,'!')
C
C      Loop over gases
       DO IG=1,NGASES
          IGAS = LISTG(IG)
          II = GORDER(IG)
C
C         Decide whether of not to use ref amnt for current gas
          USEREF=.TRUE.
          DO J=1,NREG
             IF (IGAS .EQ. IDREG(J)) USEREF=.FALSE.
          ENDDO
C
          IF (USEREF) THEN
C
C            Add gas ID to end of ref profile filename
             CWORK1=NAMREF
             WRITE(CWORK2,2220) IGAS
 2220        FORMAT(I2)
             IF (IGAS .LT. 10) THEN
                 RFNAME=CWORK1(1:LENC1) // CWORK2(2:2)
             ELSE
                 RFNAME=CWORK1(1:LENC1) // CWORK2(1:2)
             ENDIF
C
C            Read ref profile
             OPEN(UNIT=IOP2,FILE=RFNAME,FORM='FORMATTED',STATUS='OLD',
     $          IOSTAT=IERR)
             IF (IERR .NE. 0) THEN
                WRITE(6,2230) IERR, RFNAME
 2230           FORMAT('Error ',I5,' openning file:',/,A79)
                STOP
             ENDIF
             ILAY=1
 10          READ(IOP2,2240) CLINE
 2240        FORMAT(A79)
             IF (CLINE(1:1) .NE. '!') THEN
                READ(CLINE,*) J, RJUNK1, RJUNK2, RJUNK3, REFAMT(ILAY) 
                ILAY=ILAY+1
             ENDIF
             IF (ILAY .LE. MYNLAY) GOTO 10
             CLOSE(IOP2)
C
cC            IF current gas is CO2, scale ref amount
c             IF (IGAS .EQ. IDCO2) THEN
c                DO ILAY=1,MYNLAY
c                   REFAMT(ILAY)=CO2MLT*REFAMT(ILAY)
c                ENDDO
c             ENDIF
C
          ELSE
C            Copy layers gas amnt info into ref amnt array
             DO ILAY=1,MYNLAY
                REFAMT(ILAY)=GASAMT(ILAY,II)
             ENDDO
          ENDIF

C         Loop over layers
          DO ILAY=1,MYNLAY
             IPATH=(IG-1)*MYNLAY + ILAY
C
             WRITE(IOP,1220) IPATH, CHA(IGAS), HBOUND(ILAY)/1000,
     $          HBOUND(ILAY+1)/1000, PBOUND(ILAY), PBOUND(ILAY+1),
     $          (HBOUND(ILAY+1)-HBOUND(ILAY))/1000, 0.0
 1220        FORMAT('! PATH',I4,1X,A9,' HEIGHTS:',F8.3,' -',F8.3,
     $          ' km,',1PE10.3,' -',E10.3,' mb.',/,
     $          '! RAY LENGTH =',0PF9.4,' km, THETA =',1PE11.4,'.')
C
ccc             WRITE(IOP,1240) IGAS, GASAMT(ILAY,II),
             WRITE(IOP,1240) IGAS, REFAMT(ILAY),
     $          TAVG(ILAY)+TOFF, DELT(ILAY), PAVG(ILAY),
     $          (PBOUND(ILAY)-PBOUND(ILAY+1))/1013.25,
     $          PARTPP(II,ILAY), 0.5*(HBOUND(ILAY)+HBOUND(ILAY+1))/1000
 1240        FORMAT(I3,',',1PE12.4,',',0PF9.3,',',
     $          0PF9.3,',',3(1PE12.4,','),0PF9.3)
C
          ENDDO
       ENDDO
C
C      --------------
C      Path summaries
C      --------------
       WRITE(IOP,1300)
 1300  FORMAT('!',/'!')
C
       DO 40 IG=1,NGASES
          II=GORDER(IG)
          COLTOT(IG) = 0.0
          RAYTOT(IG) = 0.0
          DO 50 ILAY=1,MYNLAY
             IPATH = (IG-1)*MYNLAY + ILAY
             COLTOT(IG)=COLTOT(IG) + GASAMT(ILAY,II)
             RAYTOT(IG)=RAYTOT(IG) + (HBOUND(ILAY+1)-HBOUND(ILAY))/1000
   50     CONTINUE
C
          IPS = (IG-1)*MYNLAY + 1
          IPF = IG*MYNLAY
C
          WRITE(IOP,1320) IPS, IPF, LISTG(IG), CHA(LISTG(IG)),
     $       COLTOT(IG), RAYTOT(IG)
 1320     FORMAT(
     $    '!  PATHS ',I4,' -- ',I4,/,
     $    '!  GAS ID',I3,1X,A9,/,
     $    '!  TOTAL GAS COLUMN AMOUNT  [kiloMoles/cm2] =',1PE11.4,/,
     $    '!  TOTAL RAY PATH LENGTH               [km] =',0PF11.3,/,
     $    '! ')
   40  CONTINUE
C
       RETURN
       END
